@@ -17,8 +17,8 @@ class InvalidArgsError(Exception):
 
 _orekit._set_exception_types(JavaError, InvalidArgsError)
 
-VERSION = "11.0"
-CLASSPATH = [os.path.join(__module_dir__, "orekit-11.0.jar"), os.path.join(__module_dir__, "hipparchus-core-2.0.jar"), os.path.join(__module_dir__, "hipparchus-fitting-2.0.jar"), os.path.join(__module_dir__, "hipparchus-filtering-2.0.jar"), os.path.join(__module_dir__, "hipparchus-geometry-2.0.jar"), os.path.join(__module_dir__, "hipparchus-ode-2.0.jar"), os.path.join(__module_dir__, "hipparchus-optim-2.0.jar"), os.path.join(__module_dir__, "hipparchus-stat-2.0.jar")]
+VERSION = "11.0.1"
+CLASSPATH = [os.path.join(__module_dir__, "orekit-11.0.1.jar"), os.path.join(__module_dir__, "hipparchus-core-2.0.jar"), os.path.join(__module_dir__, "hipparchus-fitting-2.0.jar"), os.path.join(__module_dir__, "hipparchus-filtering-2.0.jar"), os.path.join(__module_dir__, "hipparchus-geometry-2.0.jar"), os.path.join(__module_dir__, "hipparchus-ode-2.0.jar"), os.path.join(__module_dir__, "hipparchus-optim-2.0.jar"), os.path.join(__module_dir__, "hipparchus-stat-2.0.jar")]
 CLASSPATH = os.pathsep.join(CLASSPATH)
 _orekit.CLASSPATH = CLASSPATH
 _orekit._set_function_self(_orekit.initVM, _orekit)
